"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.base32 = void 0;
const helper_1 = require("./helper");
class base32 extends helper_1.helper {
    constructor() {
        super(); //to call constructor dari base_helper
        this.base32_character = "ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789abcdefghijklmnopqrstuvwxyz";
    }
    base32_encode(input) {
        const base32_character = this.base32_character;
        let encoded = "";
        let bits = 0;
        let value = 0;
        for (let i = 0; i < input.length; i++) {
            value = (value << 8) | input.charCodeAt(i);
            bits += 8;
            while (bits >= 5) {
                encoded += base32_character[(value >>> (bits - 5)) & 0x1f];
                bits -= 5;
            }
        }
        if (bits > 0) {
            value <<= 5 - bits;
            encoded += base32_character[value & 0x1f];
        }
        return encoded;
    }
    base32_decode(input) {
        const base32_character = this.base32_character;
        let decoded = "";
        let bits = 0;
        let value = 0;
        for (let i = 0; i < input.length; i++) {
            const char = input.charAt(i);
            const charValue = base32_character.indexOf(char);
            if (charValue === -1) {
                throw new Error("Invalid base32 character");
            }
            value = (value << 5) | charValue;
            bits += 5;
            if (bits >= 8) {
                decoded += String.fromCharCode((value >>> (bits - 8)) & 0xff);
                bits -= 8;
            }
        }
        return decoded;
    }
}
exports.base32 = base32;
