"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.codex = void 0;
const helper_1 = require("./helper");
class codex extends helper_1.helper {
    constructor() {
        super(...arguments);
        this.base32_chars = "ABCDEFGHIJKLMNOPQRSTUVWXYZ234567";
    }
    // Encode a string to Base32
    base32_encode(input) {
        input = Buffer.from(input, "utf-8");
        let output = "";
        let buffer = 0;
        let bufferLength = 0;
        for (let i = 0; i < input.length; i++) {
            buffer = (buffer << 8) | input[i];
            bufferLength += 8;
            while (bufferLength >= 5) {
                const index = (buffer >> (bufferLength - 5)) & 0x1f;
                output += this.base32_chars[index];
                bufferLength -= 5;
            }
        }
        if (bufferLength > 0) {
            const index = (buffer << (5 - bufferLength)) & 0x1f;
            output += this.base32_chars[index];
        }
        return output;
    }
    // Decode a Base32 string to a string
    base32_decode(input) {
        let output = [];
        let buffer = 0;
        let bufferLength = 0;
        for (let i = 0; i < input.length; i++) {
            const char = input.charAt(i);
            const charIndex = this.base32_chars.indexOf(char);
            if (charIndex === -1) {
                throw new Error(`Invalid Base32 character: ${char}`);
            }
            buffer = (buffer << 5) | charIndex;
            bufferLength += 5;
            if (bufferLength >= 8) {
                output.push((buffer >> (bufferLength - 8)) & 0xff);
                bufferLength -= 8;
            }
        }
        let results = Buffer.from(output);
        return results.toString("utf-8");
    }
}
exports.codex = codex;
