"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.fs = void 0;
const helper_1 = require("./helper");
const fs_1 = require("fs");
const path_1 = __importDefault(require("path"));
class fs extends helper_1.helper {
    constructor() {
        super(); //to call constructor dari base_helper
        this.dir = this.base_path();
    }
    // Base path into project folder not a package
    base_path() {
        var _a;
        let dir = (_a = require.main) === null || _a === void 0 ? void 0 : _a.filename;
        return path_1.default.dirname(dir + "/");
    }
    path(filename) {
        return path_1.default.join(this.dir + "/" + filename);
    }
    // Read file
    read(filename) {
        return __awaiter(this, void 0, void 0, function* () {
            let file_path = this.path(filename);
            try {
                let results = yield fs_1.promises.readFile(file_path, {
                    encoding: "utf-8",
                });
                return results;
            }
            catch (err) {
                this.error("fs", err);
            }
            return file_path;
        });
    }
    // Write file with the folder
    write(filename, data) {
        return __awaiter(this, void 0, void 0, function* () {
            let file_path = this.path(filename);
            let directory_path = path_1.default.dirname(file_path);
            try {
                yield fs_1.promises.mkdir(directory_path, { recursive: true });
                yield fs_1.promises.writeFile(file_path, data, {
                    flag: fs_1.constants.O_WRONLY | fs_1.constants.O_CREAT,
                    encoding: "utf-8",
                });
            }
            catch (err) {
                this.error("fs", err);
            }
            return file_path;
        });
    }
    // Destroy a file or folder recrusively
    destroy(filename) {
        return __awaiter(this, void 0, void 0, function* () {
            let file_path = this.path(filename);
            try {
                yield fs_1.promises.access(file_path, fs_1.constants.F_OK);
                yield fs_1.promises.rm(file_path, { recursive: true });
            }
            catch (err) {
                if (err.code !== "ENOENT") {
                    this.error("fs", err);
                }
                else {
                    this.error("fs", err);
                }
            }
        });
    }
}
exports.fs = fs;
